summaryrefslogtreecommitdiff
path: root/yarnlib/elements.py
diff options
context:
space:
mode:
authorLars Wirzenius <liw@liw.fi>2013-06-19 20:42:58 +0100
committerLars Wirzenius <liw@liw.fi>2013-06-19 20:42:58 +0100
commit2c288169fd38032575feb4414c039e9c1e9e8764 (patch)
tree365b3467e08cac322943ce00830dfb140fcfb77a /yarnlib/elements.py
parent54e347e461327c09746b45d19b1d24631652da8e (diff)
downloadcmdtest-2c288169fd38032575feb4414c039e9c1e9e8764.tar.gz
Switch to "scenario testing"
Diffstat (limited to 'yarnlib/elements.py')
-rw-r--r--yarnlib/elements.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/yarnlib/elements.py b/yarnlib/elements.py
index a1dea0d..9eeb1b7 100644
--- a/yarnlib/elements.py
+++ b/yarnlib/elements.py
@@ -16,9 +16,9 @@
# =*= License: GPL-3+ =*=
-# This is a step in a story: GIVEN, WHEN, THEN, etc.
+# This is a step in a scenario: GIVEN, WHEN, THEN, etc.
-class StoryStep(object):
+class ScenarioStep(object):
def __init__(self, what, text):
self.what = what
@@ -26,9 +26,9 @@ class StoryStep(object):
self.implementation = None
-# This is the story itself.
+# This is the scenario itself.
-class Story(object):
+class Scenario(object):
def __init__(self, name):
self.name = name